function [LQ,CUM] = LQ_est(data,nwt,p,q)
%
%% function [LQ,CUM] = LQ_est(data,nwt,p,q)
%
% Computes non-Gaussian multiscale expansion coefficients as defined in
%
% H. Wendt, P. Abry, K. Kiyono, J. Hayano, E. Watanabe, Y. Yamamoto,
% "Wavelet p-Leader Non Gaussian Multiscale Expansions for Heart Rate
% Variability Analysis in Congestive Heart Failure Patients," IEEE T.
% Biomedical Engineering, 2018.    
%
%% Input
% data -    time series or image to analyze
% nwt -     wavelet (Daubes-chies, nwt>=1)
% p -       p-norm of p-leaders, 0 < p <= +infinity
% q -       pairs of moments for non-Gaussian expansion coefficients
%
%% Output
%
% LQ -      vector of scale-wise non-Gaussian expansion coefficients 
%           as defined in Eq. (8) the above reference
% CUM -     scale-wise log-cumulants of order 1 to 4 of p-leaders
%
%
%% If you use this code, please cite
%
% H. Wendt, P. Abry, K. Kiyono, J. Hayano, E. Watanabe, Y. Yamamoto,
% "Wavelet p-Leader Non Gaussian Multiscale Expansions for Heart Rate
% Variability Analysis in Congestive Heart Failure Patients," IEEE T.
% Biomedical Engineering, 2018.    
%
%% and
%
% H. Wendt, P. Abry, S. Jaffard, "Bootstrap for empirical multifractal
% analysis," IEEE Signal Proces. Mag., vol. 24, no. 4, pp. 38-48, 2007.   


mf_obj = MF_BS_tool_inter;
mf_obj.nwt = nwt;
mf_obj.method_mrq = [1 2];    % 1: Wavelet coefficients, 2: wavelet leaders
mf_obj.j1      = 1;
mf_obj.j2      = 3;
mf_obj.p = p;
mf_obj.q       = q;
mf_obj.cum     = 4;
mf_obj.gamint = 0;
mf_obj.fig_num = 1;
mf_obj.verbosity = 0; 
warning off
mf_obj.analyze (data(:));
warning on
zid = mf_obj.get_zid (); cid = mf_obj.get_cid ();
CUM = mf_obj.logstat.LWT.est(cid, :);  % Cumulants C_m(j)
sf_zq  = mf_obj.logstat.LWT.est(zid, :);  % Structure functions log_2 S(q,j)

LQ=zeros(size(sf_zq(1,:)));
for i=1:length(q);
    LQ=LQ+(-1)^(i+1)*sf_zq(i,:)/q(i);
end
    
