%% Demo for computing non Gaussian multiscale expansion coefficients.
% 
%% If you use this code, please cite
%
% H. Wendt, P. Abry, K. Kiyono, J. Hayano, E. Watanabe, Y. Yamamoto,
% "Wavelet p-Leader Non Gaussian Multiscale Expansions for Heart Rate
% Variability Analysis in Congestive Heart Failure Patients," IEEE T.
% Biomedical Engineering, 2018.    
%
%% and
%
% H. Wendt, P. Abry, S. Jaffard, "Bootstrap for empirical multifractal
% analysis," IEEE Signal Proces. Mag., vol. 24, no. 4, pp. 38-48, 2007.   


% The p-leaders multifractal analysis toolbox is needed for computing the
% non Gaussian multiscale indices.
%
% It can be downloaded for free here:
%
%   https://www.irit.fr/~Herwig.Wendt/software.html#plbmf
%
% Then add the path and subpaths to it:

addpath(genpath('MF_BS_tool_webrelease'))

clear all;

% load example data
load('example_data.mat');
% the demo data contains 3 different time series:
%
% data{1} - fractional Brownian motion (fBm): self-similar, monofractal
% data{2} - multifractal randiom walk (mrw): multifractal of log-normal type
% data{3} - compound Poisson process (cpc): multifractal of general type
TTS{1}='fbm';TTS{2}='mrw';TTS{3}='cpc';
PSTR{1}='bo-';PSTR{2}='rd-';PSTR{3}='ks-';

%% Setup Analysis

nwt = 3;    % Wavelet (Daubechies), nwt >= 1
p = 1;      % p for p-leaders , 0 < p <= infty

% pairs of moment orders q: 4 different non Gaussian expansion coefficients
q1 = [0.25 2];
q2 = [-2 2];
q3 = [0.25 0.75 2.5 2];
q4 = [-2.5 2 2.5 -2];

CM=10; % max. cumulant weight to evaluate

for m=1:CM;
    CW1(m)=(q1(1)^(m-1) - q1(2)^(m-1))/factorial(m);
    CW2(m)=(q2(1)^(m-1) - q2(2)^(m-1))/factorial(m);
    CW3(m)=(q3(1)^(m-1) - q3(2)^(m-1) + q3(3)^(m-1) - q3(4)^(m-1))/factorial(m);
    CW4(m)=(q4(1)^(m-1) - q4(2)^(m-1) + q4(3)^(m-1) - q4(4)^(m-1))/factorial(m);
end
figure(11);
subplot(221);plot(CW1,'bo-');grid on;axis tight;xlabel('cumulant order m'); ylabel('weight'); title('Lq q=[0.25 2]');hold off;
subplot(222);plot(CW2,'bo-');grid on;axis tight;xlabel('cumulant order m'); ylabel('weight'); title('Lq q=[-2 2]');hold off;
subplot(223);plot(CW3,'bo-');grid on;axis tight;xlabel('cumulant order m'); ylabel('weight'); title('Lq q=[0.25 0.75 2.5 2];');hold off;
subplot(224);plot(CW4,'bo-');grid on;axis tight;xlabel('cumulant order m'); ylabel('weight'); title('Lq q=[-2.5 2 2.5 -2]');hold off;

%% non Gaussian multiscale analysis



% loop data, analyze and plot non-Gaussian indices and cumulants
figure(1);clf;figure(2);clf;
for pid=1:3;
    [LQ1{pid},CUM{pid}] = LQ_est(data{pid},nwt,p,q1);
    [LQ2{pid}] = LQ_est(data{pid},nwt,p,q2);
    [LQ3{pid}] = LQ_est(data{pid},nwt,p,q3);
    [LQ4{pid}] = LQ_est(data{pid},nwt,p,q4);

    % Plots
    figure(1);
    subplot(221);hold on;plot(LQ1{pid},PSTR{pid});grid on;axis tight;xlabel('log_2(scale)'); title('Lq q=[0.25 2]');hold off;
    subplot(222);hold on;plot(LQ2{pid},PSTR{pid});grid on;axis tight;xlabel('log_2(scale)'); title('Lq q=[-2 2]');hold off;
    subplot(223);hold on;plot(LQ3{pid},PSTR{pid});grid on;axis tight;xlabel('log_2(scale)'); title('Lq q=[0.25 0.75 2.5 2];');hold off;
    subplot(224);hold on;plot(LQ4{pid},PSTR{pid});grid on;axis tight;xlabel('log_2(scale)'); title('Lq q=[-2.5 2 2.5 -2]');hold off;
    figure(2);
    subplot(221);hold on;plot(CUM{pid}(1,:),PSTR{pid});grid on;axis tight;xlabel('log_2(scale)'); title('Cumulant 1');hold off;
    subplot(222);hold on;plot(CUM{pid}(2,:),PSTR{pid});grid on;axis tight;xlabel('log_2(scale)'); title('Cumulant 2');hold off;
    subplot(223);hold on;plot(CUM{pid}(3,:),PSTR{pid});grid on;axis tight;xlabel('log_2(scale)'); title('Cumulant 3');hold off;
    subplot(224);hold on;plot(CUM{pid}(4,:),PSTR{pid});grid on;axis tight;xlabel('log_2(scale)'); title('Cumulant 4'); hold off;

end
figure(1);subplot(221);legend(TTS,'location','southeast');figure(2);subplot(221);legend(TTS);

